==> edge-login-ui-rn-0.9.23.tgz: package/lib/components/common/AlertDropdown.js <==
import * as React from 'react';
import { Text, View } from 'react-native';
import { AirshipDropdown } from 'react-native-airship';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import EntypoIcon from 'react-native-vector-icons/Entypo';
import s from '../../common/locales/strings';
import { withTheme } from '../services/ThemeContext';
function AlertDropdownComponent(props) {
    const { bridge, message, theme, warning } = props;
    const styles = getStyles(theme);
    return (React.createElement(AirshipDropdown, { bridge: bridge, backgroundColor: warning ? theme.dropdownWarning : theme.dropdownError },
        React.createElement(View, { style: styles.container },
            React.createElement(EntypoIcon, { name: "warning", size: theme.rem(1.25), style: styles.icon }),
            React.createElement(Text, { style: styles.text },
                React.createElement(Text, { style: styles.boldText },
                    warning
                        ? s.strings.alert_dropdown_warning
                        : s.strings.alert_dropdown_alert,
                    ' '),
                message),
            React.createElement(AntDesignIcon, { name: "closecircle", size: theme.rem(1), style: styles.icon }))));
}
const getStyles = cacheStyles((theme) => ({
    container: {
        padding: theme.rem(0.5),
        alignItems: 'center',
        flexDirection: 'row',
        justifyContent: 'space-between'
    },
    icon: {
        color: theme.dropdownText,
        textAlign: 'center',
        minWidth: theme.rem(1.5)
    },
    text: {
        fontSize: theme.rem(0.75),
        color: theme.dropdownText,
        marginHorizontal: theme.rem(0.5)
    },
    boldText: {
        fontWeight: theme.fontWeightBold
    }
}));
export const AlertDropdown = withTheme(AlertDropdownComponent);

==> edge-login-ui-rn-2.12.0.tgz: package/lib/components/common/AlertDropdown.js <==
import * as React from 'react';
import { Text, View } from 'react-native';
import { AirshipDropdown } from 'react-native-airship';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import EntypoIcon from 'react-native-vector-icons/Entypo';
import s from '../../common/locales/strings';
import { withTheme } from '../services/ThemeContext';
function AlertDropdownComponent(props) {
    const { bridge, message, theme, warning } = props;
    const styles = getStyles(theme);
    return (React.createElement(AirshipDropdown, { bridge: bridge, backgroundColor: warning ? theme.dropdownWarning : theme.dropdownError },
        React.createElement(View, { style: styles.container },
            React.createElement(EntypoIcon, { name: "warning", size: theme.rem(1.25), style: styles.icon }),
            React.createElement(Text, { style: styles.text },
                React.createElement(Text, { style: styles.boldText },
                    warning
                        ? s.strings.alert_dropdown_warning
                        : s.strings.alert_dropdown_alert,
                    ' '),
                message),
            React.createElement(AntDesignIcon, { name: "closecircle", size: theme.rem(1), style: styles.icon }))));
}
const getStyles = cacheStyles((theme) => ({
    container: {
        padding: theme.rem(0.5),
        alignItems: 'center',
        flexDirection: 'row',
        justifyContent: 'space-between'
    },
    icon: {
        color: theme.dropdownText,
        textAlign: 'center',
        minWidth: theme.rem(1.5)
    },
    text: {
        fontSize: theme.rem(0.75),
        color: theme.dropdownText,
        marginHorizontal: theme.rem(0.5),
        flexShrink: 1
    },
    boldText: {
        fontWeight: theme.fontWeightBold
    }
}));
export const AlertDropdown = withTheme(AlertDropdownComponent);
